@@ -1,13 +1,23 @@
 import logging
 
 from clikit.api.io import flags as verbosity
+from loguru import logger
+
+LOGGING_VERBOSE = 18
+LOGGING_VERY_VERBOSE = 16
+
+logger.level("VERBOSE", LOGGING_VERBOSE, color="<bold>", icon="🔈️")
+logger.level("VERY_VERBOSE", LOGGING_VERY_VERBOSE, color="<bold>", icon="🔊")
 
 _levels = {
-    logging.CRITICAL: verbosity.NORMAL,
-    logging.ERROR: verbosity.NORMAL,
-    logging.WARNING: verbosity.NORMAL,
-    logging.INFO: verbosity.NORMAL,
-    logging.DEBUG: verbosity.DEBUG,
+    logger.level("CRITICAL").no: verbosity.NORMAL,
+    logger.level("ERROR").no: verbosity.NORMAL,
+    logger.level("WARNING").no: verbosity.NORMAL,
+    logger.level("SUCCESS").no: verbosity.NORMAL,
+    logger.level("INFO").no: verbosity.NORMAL,
+    logger.level("VERBOSE").no: verbosity.VERBOSE,
+    logger.level("VERY_VERBOSE").no: verbosity.VERY_VERBOSE,
+    logger.level("DEBUG").no: verbosity.DEBUG,
 }
 
 
@@ -20,7 +30,8 @@ class ClikitHandler(logging.Handler):
 
     def emit(self, record: logging.LogRecord):
         level = _levels[record.levelno]
-        self.write_line(level, record)
+        if self.io.verbosity <= verbosity.VERY_VERBOSE:
+            self.write_line(level, record)
 
     def write_line(self, level: int, record: logging.LogRecord):
         if record.levelno >= logging.WARNING:
@@ -36,5 +47,5 @@ class ClikitDebuggerHandler(ClikitHandler):
 
     def emit(self, record: logging.LogRecord):
         level = _levels[record.levelno]
-        if self.io.verbosity >= verbosity.VERBOSE:
+        if self.io.verbosity > verbosity.VERY_VERBOSE:
             self.write_line(level, record)
