@@ -1,12 +1,17 @@
 import cleo
 
 from pyadr import __version__
-from pyadr.cli import LoggingAppConfig
+from pyadr.cli.config import LoggingAppConfig
 from pyadr.git.cli.commands import (
+    GitAcceptCommand,
+    GitCommitCommand,
     GitConfigCommand,
+    GitHelperCommand,
     GitInitCommand,
     GitNewCommand,
+    GitPreMergeChecksCommand,
     GitProposeCommand,
+    GitRejectCommand,
 )
 
 
@@ -20,3 +25,8 @@ class App(cleo.Application):
         self.add(GitInitCommand())
         self.add(GitNewCommand())
         self.add(GitProposeCommand())
+        self.add(GitAcceptCommand())
+        self.add(GitRejectCommand())
+        self.add(GitCommitCommand())
+        self.add(GitHelperCommand())
+        self.add(GitPreMergeChecksCommand())
